#
# spec file for package libmysofa
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 0
%define __builder ninja
Name:           libmysofa
Version:        0.9.1
Release:        lp152.3.3.1
Summary:        Reader for AES SOFA HRTF files
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://github.com/hoene/libmysofa
Source0:        https://github.com/hoene/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source99:       baselibs.conf
# PATCH-FIX-UPSTREAM gh#hoene/libmysofa#130
Patch1:         0001-Fix-negative-values-for-malloc.patch
# PATCH-FIX-UPSTREAM gh#hoene/libmysofa#136 - CVE-2020-36152 - boo#1181977
Patch2:         0002-dataobject.c-fix-stack-buffer-overflow.patch
# PATCH-FIX-UPSTREAM gh#hoene/libmysofa#138 - CVE-2020-36148 - boo#1181981
#                    gh#hoene/libmysofa#137 - CVE-2020-36149 - boo#1181980
Patch3:         0003-tools.c-Fix-NULL-pointer-derefs.patch
# PATCH-FIX-UPSTREAM gh#hoene/libmysofa#134 - CVE-2020-36151 - boo#1181978
#                    gh#hoene/libmysofa#135 - CVE-2020-36150 - boo#1181979
Patch4:         0004-loudness.c-fix-heap-buffer-overflow.patch
# PATCH-FIX-UPSTREAM gh#hoene/libmysofa#96 - CVE-2020-6860 - boo#1182883
Patch5:         0005-Fixed-an-additional-recursive-problem.patch
BuildRequires:  c++_compiler
BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  pkgconfig
# for tests
# BuildRequires:  nodejs-common
BuildRequires:  pkgconfig(cunit)
BuildRequires:  pkgconfig(zlib)

%description
This is a C library to read AES SOFA files that contain HRTFs stored
according to the AES69-2015 standard.

%package -n %{name}%{sover}
Summary:        Reader for AES SOFA HRTF files
Group:          System/Libraries

%description -n %{name}%{sover}
This is a C library to read AES SOFA files that contain HRTFs stored
according to the AES69-2015 standard.

%package devel
Summary:        Development headers and libraries for libmysofa
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sover} = %{version}

%description devel
This is a C library to read AES SOFA files that contain HRTFs stored
according to the AES69-2015 standard.

This package contains the development libraries and headers for libmysofa.

%prep
%autosetup -p1

%build
%cmake
%cmake_build

%install
%cmake_install
rm %{buildroot}%{_libdir}/%{name}.a

# test suite is broken
# %%check
# %%cmake_build -C build test

%post -n %{name}%{sover} -p /sbin/ldconfig
%postun -n %{name}%{sover} -p /sbin/ldconfig

%files -n %{name}%{sover}
%doc README.md
%license LICENSE
%{_bindir}/mysofa2json
%{_datadir}/%{name}
%{_libdir}/%{name}.so.%{sover}*

%files devel
%{_includedir}/mysofa.h
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Mon Mar 15 2021 Mia Herkt <mia@0x0.st>
- Added security backports:
  * 0001-Fix-negative-values-for-malloc.patch
    gh#hoene/libmysofa#130
  * 0002-dataobject.c-fix-stack-buffer-overflow.patch
    gh#hoene/libmysofa#136 - CVE-2020-36152 - boo#1181977
  * 0003-tools.c-Fix-NULL-pointer-derefs.patch
    gh#hoene/libmysofa#138 - CVE-2020-36148 - boo#1181981
    gh#hoene/libmysofa#137 - CVE-2020-36149 - boo#1181980
  * 0004-loudness.c-fix-heap-buffer-overflow.patch
    gh#hoene/libmysofa#134 - CVE-2020-36151 - boo#1181978
    gh#hoene/libmysofa#135 - CVE-2020-36150 - boo#1181979
  * 0005-Fixed-an-additional-recursive-problem.patch
    gh#hoene/libmysofa#96 - CVE-2020-6860 - boo#1182883
* Sun Jan  5 2020 Martin Herkt <9+suse@cirno.systems>
- Update to version 0.9.1
  * Extended angular neighbor search to 'close the sphere'
  * Added and exposed mysofa_getfilter_float_nointerp method
  * Fixed various security issues
    CVE-2019-16091 - boo#1149919
    CVE-2019-16092 - boo#1149920
    CVE-2019-16093 - boo#1149922
    CVE-2019-16094 - boo#1149924
    CVE-2019-16095 - boo#1149926
    CVE-2019-20016 - boo#1159839
    CVE-2019-20063 - boo#1160040
- Drop libmysofa-0-pkgconfig-paths.patch
* Sun Mar 31 2019 Martin Herkt <9+suse@cirno.systems>
- Update to version 0.7
  * fixed two important security holes
    CVE-2019-10672
    boo#1131106
  * fixed bug mysofa_interpolate when interpolation is not needed
  * fixed bug with simple hrtf lookup
  * added advanced open function and various enhancements
  * fixed memory leak in lookup.c
- Drop libmysofa-0-gnu-install-dirs.patch
- Add libmysofa-0-pkgconfig-paths.patch
* Mon Apr 30 2018 jengelh@inai.de
- Ensure neutrality of description. Adjust RPM groups.
* Wed Apr 25 2018 9+suse@cirno.systems
- Init, 0.6
